@@ -1,7 +1,7 @@
 package Complete::Util;
 
-our $DATE = '2016-10-14'; # DATE
-our $VERSION = '0.52'; # VERSION
+our $DATE = '2016-10-18'; # DATE
+our $VERSION = '0.53'; # VERSION
 
 use 5.010001;
 use strict;
@@ -330,9 +330,6 @@ sub complete_array_elem {
             } elsif (eval { require Text::Levenshtein::Flexible; 1 }) {
                 $editdist_flex = 1;
                 \&Text::Levenshtein::Flexible::levenshtein_l;
-            } elsif (eval { require Text::Levenshtein::XS; 1 }) {
-                $editdist_flex = 0;
-                \&Text::Levenshtein::XS::distance;
             } else {
                 $editdist_flex = 0;
                 \&__editdist;
@@ -610,7 +607,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.52 of Complete::Util (from Perl distribution Complete-Util), released on 2016-10-14.
+This document describes version 0.53 of Complete::Util (from Perl distribution Complete-Util), released on 2016-10-18.
 
 =head1 DESCRIPTION
 
@@ -823,9 +820,11 @@ results in:
 
  timethis 20:  7 wallclock secs ( 6.82 usr +  0.00 sys =  6.82 CPU) @  2.93/s (n=20)
 
-Answer: you will need to install either L<Text::Levenshtein::Flexible> or
-L<Text::Levenshtein::XS> to speed up fuzzy matching (these modules are declared
-as optional prereqs). After Text::Levenshtein::Flexible is installed:
+Answer: fuzzy matching is slower than exact matching due to having to calculate
+Levenshtein distance. But if you find fuzzy matching too slow using the default
+pure-perl implementation, you might want to install
+L<Text::Levenshtein::Flexible> (an optional prereq) to speed up fuzzy matching.
+After Text::Levenshtein::Flexible is installed:
 
  timethis 20:  1 wallclock secs ( 1.04 usr +  0.00 sys =  1.04 CPU) @ 19.23/s (n=20)
 
@@ -837,10 +836,14 @@ If set to true, will display more log statements for debugging.
 
 =head2 COMPLETE_UTIL_LEVENSHTEIN => str ('pp'|'xs'|'flexible')
 
-Can be used to force which Levenshtein distance implementation to use. The
-default is to use L<Text::Levenshtein::Flexible> (XS module) that performs the
-best, then fallback to L<Text::Levenshtein::XS>, then fallback to the included
-PP implementation (which is about 1-2 orders of magnitude slower).
+Can be used to force which Levenshtein distance implementation to use. C<pp>
+means the included PP implementation, which is the slowest (1-2 orders of
+magnitude slower than XS implementations), C<xs> which means
+L<Text::Levenshtein::XS>, or C<flexible> which means
+L<Text::Levenshtein::Flexible> (performs best).
+
+If this is not set, the default is to use Text::Levenshtein::Flexible when it's
+available, then fallback to the included PP implementation.
 
 =head1 HOMEPAGE
 
